| Title: | Render 'Plotly' Maps without an Internet Connection |
|---|---|
| Description: | Includes 'JavaScript' files that allow 'plotly' maps to render without an internet connection. |
| Authors: | Carson Sievert [aut, cre] (ORCID: <https://orcid.org/0000-0002-4958-2844>) |
| Maintainer: | Carson Sievert <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.2 |
| Built: | 2026-06-05 10:32:26 UTC |
| Source: | https://github.com/cpsievert/plotlygeoassets |
This function is used by plotly to make it possible to render maps without an internet connection.
geo_assets()geo_assets()
Carson Sievert
geo_assets()geo_assets()