Welcome to ClientVPS Mirrors

Help for package plotlyGeoAssets
Title: Render 'Plotly' Maps without an Internet Connection
Version: 0.0.2
Description: Includes 'JavaScript' files that allow 'plotly' maps to render without an internet connection.
Depends: R (≥ 2.10)
Enhances: plotly
Suggests: testthat, htmltools
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
URL: https://github.com/cpsievert/plotlyGeoAssets
BugReports: https://github.com/cpsievert/plotlyGeoAssets/issues
NeedsCompilation: no
Packaged: 2019-01-08 16:09:40 UTC; cpsievert
Author: Carson Sievert ORCID iD [aut, cre]
Maintainer: Carson Sievert <cpsievert1@gmail.com>
Repository: CRAN
Date/Publication: 2019-01-08 16:50:02 UTC

Obtain plotly's geo assets as an htmlDependency object

Description

This function is used by plotly to make it possible to render maps without an internet connection.

Usage

geo_assets()

Author(s)

Carson Sievert

Examples


geo_assets()

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.